@@ -80,7 +80,7 @@ class Rethink_DBS(GeneralData):
                 dbname = self.dbname
                 dbhost = self.address[0]
                 dbport = self.address[1]
-                self.session, self.reader, self.writer = await self.r.connect(db=dbname,
+                self.session = await self.r.connect(db=dbname,
                                                     host=dbhost,
                                                     port=dbport,
                                                     **kwargs)
@@ -125,7 +125,8 @@ class Rethink_DBS(GeneralData):
     async def close(self):
         if self.session:
             await self.session.close(noreply_wait=False)
-            await self.writer.wait_closed()
+            if self.writer:
+                await self.writer.wait_closed()
             del self.session
             self.session = None
 
